"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  SwarmappApi: () => SwarmappApi
});
module.exports = __toCommonJS(src_exports);
var import_axios = __toESM(require("axios"));
var import_querystring = __toESM(require("querystring"));

// src/utils.ts
var between = (min, max) => {
  return Math.floor(Math.random() * (max - min) + min);
};
var createLatLngString = (lat, lng) => {
  return `${lat},${lng}`;
};

// src/index.ts
var SwarmappApi = class {
  constructor(oauth_token) {
    this.config = {
      m: "swarm",
      v: "20221101",
      // A random coordinate to use between calls imitating regular behavior
      ll: createLatLngString("26.30" + between(34e10, 499999999999), "50.1" + between(287e10, 3119999999999)),
      //latitude/longitude
      altAcc: "30.000000",
      llAcc: "14.825392",
      floorLevel: "2146959360",
      alt: "12.275661"
    };
    this.basePath = "https://api.foursquare.com/v2/";
    this.headers = {
      "User-Agent": "com.foursquare.robin.ios.phone:20230316.2230.52:20221101:iOS 16.1.1:iPhone13,4"
    };
    if (oauth_token) {
      this.config.oauth_token = oauth_token;
    }
  }
  async initialize() {
    try {
      const response = await this.getUser();
      this.user = response?.data?.response?.user;
      this.log("working \u2705");
    } catch (error) {
      this.error("Could not authenticate user");
    }
  }
  async initiatemultifactorlogin(username, password, client_id, client_secret) {
    const params = {
      ...this.config,
      client_id,
      client_secret,
      username,
      password
    };
    try {
      const response = await import_axios.default.post(this.basePath + "private/initiatemultifactorlogin", import_querystring.default.stringify(params));
      this.flowId = response.data.flowId;
      return response.data;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  async completemultifactorlogin(code, client_id, client_secret) {
    const params = {
      ...this.config,
      client_id,
      client_secret,
      code,
      flowId: this.flowId
    };
    try {
      const response = await import_axios.default.post(this.basePath + "private/completemultifactorlogin", import_querystring.default.stringify(params));
      this.config.oauth_token = response.data.oauth_token;
      return response.data.access_token;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  // Get Commands
  // TODO: requires testing, does not accept non swarmapp (mobile) oauth tokens
  async getFriends(user_id = "self") {
    this.config.user_id = user_id;
    try {
      const result = await import_axios.default.get(this.basePath + "users/" + user_id + "/friends", { "params": this.config });
      return result.data.response.friends;
    } catch (error) {
      this.error(error.response.data);
    }
  }
  // TODO: works only for foursquare client, requires more testing
  async getFollowings(user_id = "self") {
    this.config.m = "foursquare";
    this.config.user_id = user_id;
    try {
      const result = await import_axios.default.get(this.basePath + "users/" + user_id + "/following", { "params": this.config });
      return result.data.response.following;
    } catch (error) {
      this.error(error.response.data);
    }
  }
  // TODO: works only for foursquare client, requires more testing
  async getFollowers(user_id = "self") {
    this.config.m = "foursquare";
    this.config.user_id = user_id;
    try {
      const result = await import_axios.default.get(this.basePath + "users/" + user_id + "/followers", { "params": this.config });
      return result.data.response.followers;
    } catch (error) {
      this.error(error.response.data);
    }
  }
  // TODO: should get user, then get checkins and location of last check-in
  getLastSeen(user_id = "self", limit = 100) {
    this.config.user_id = user_id;
    this.config.limit = limit;
    try {
      return this.getUser(user_id);
    } catch (error) {
      this.error(error.response.data);
    }
  }
  async getUser(user_id = "self") {
    try {
      const result = await import_axios.default.get(`${this.basePath}users/${user_id}`, { "params": this.config });
      return result;
    } catch (error) {
      throw new Error("Error getting user data, maybe an authentication error ?");
      return;
    }
  }
  async getVenue(venue_id) {
    try {
      const result = await import_axios.default.get(`${this.basePath}venues/${venue_id}/`, { "params": this.config });
      return result.data.response.venue;
    } catch (error) {
      throw new Error("Error getting venue data, maybe an authentication error ?");
      return;
    }
  }
  async getCheckins(user_id = "self", limit = 100, afterTimestamp) {
    if (typeof afterTimestamp !== "undefined") {
      this.config.afterTimeStamp = afterTimestamp;
    }
    this.config.user_id = user_id;
    this.config.limit = limit;
    try {
      const result = await import_axios.default.get(this.basePath + "users/" + user_id + "/checkins", { "params": this.config });
      return result;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  // not sure if it is working
  async getGeos(user_id = "self") {
    this.config.user_id = user_id;
    delete this.config.afterTimeStamp;
    try {
      const response = await import_axios.default.get(this.basePath + "/users/" + user_id + "/map", { "params": this.config });
      return response.data.response;
    } catch (error) {
      this.error(error.response.data);
    }
  }
  // returns user timeline after timestamp
  async getRecent(limit = 100, ll) {
    this.config.limit = limit;
    this.config.afterTimeStamp = (Math.floor(Date.now() / 1e3) - 1 * 24 * 60 * 60).toString();
    if (typeof ll !== "undefined") {
      this.log("found location");
      this.config.ll = ll;
    }
    try {
      const result = await import_axios.default.get(this.basePath + "checkins/recent", {
        params: this.config,
        paramsSerializer: (params) => {
          return import_querystring.default.stringify(params);
        }
      });
      return result.data.response.recent;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  // Get Trending Venues
  async getTrending(limit = 50, ll, near, radius = 1e5) {
    this.config.limit = limit;
    this.config.radius = radius;
    if (typeof ll !== "undefined") {
      this.config.ll = ll;
    } else {
      this.config.near = near;
    }
    try {
      const result = await import_axios.default.get(this.basePath + "venues/trending", {
        params: this.config,
        paramsSerializer: (params) => {
          return import_querystring.default.stringify(params);
        }
      });
      return result.data.response.venues;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  // Checkin Functions
  async checkIn(venue_id, silent) {
    if (silent) {
      this.config.broadcast = "private";
    }
    this.config.venueId = venue_id;
    const venue_info = await this.getVenue(venue_id);
    this.config.ll = createLatLngString(venue_info.location.lat, venue_info.location.lng);
    try {
      const result = await import_axios.default.post(this.basePath + "checkins/add", import_querystring.default.stringify(this.config));
      const checkin = result.data.response?.checkin;
      return checkin;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  // Suspect this method to update user location, doesn't work
  async private_log() {
    const FormData = require("form-data");
    const formData = new FormData();
    formData.append("altAcc", this.config.altAcc);
    formData.append("llAcc", this.config.llAcc);
    formData.append("floorLevel", this.config.floorLevel);
    formData.append("alt", this.config.alt);
    formData.append("csid", "1243");
    formData.append("v", this.config.v);
    formData.append("oauth_token", this.config.oauth_token);
    formData.append("m", this.config.m);
    formData.append("ll", this.config.ll);
    formData.append("background", "true");
    const script = [{ "name": "ios-metrics", "csid": 1243, "ctc": 4, "metrics": [{ "rid": "642a1e4371f95f2eb16b8eda", "n": "SwarmTimelineFeedViewController", "im": "3-3", "vc": 1 }], "event": "background", "cts": 1680481860378182e-6 }];
    const stringified = JSON.stringify(script);
    formData.append("loglines", stringified, { filename: "loglines", contentType: "application/json" });
    try {
      const result = await import_axios.default.post(this.basePath + "private/log", formData, {
        headers: {
          ...formData.getHeaders()
        }
      });
      return result;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  async register_device() {
    const params = {
      limitAdsTracking: "1",
      carrier: "stc",
      hasWatch: "1",
      csid: "1242",
      alt: "11.791945",
      llAcc: "14.825392",
      otherDeviceIds: "6054750ee01fbc1e3492a745,61187d1fceb2110097a0fc02",
      ll: "21.530136,39.172863",
      altAcc: "17.547791",
      locationAuthorizationStatus: "authorizedwheninuse",
      token: "ec0718c5d042b63587c14d461bb077d1262811456c4799558e1df2616f02cc9a",
      oauth_token: "DW233H4JWJZ0E14QU01LFWUZL4RDQPLAF10BAJEI2FTWNOKH",
      iosSettings: "0",
      m: "swarm",
      floorLevel: "2146959360",
      measurementSystem: "metric",
      uniqueDevice: "6054750ee01fbc1e3492a745",
      v: "20221101",
      backgroundRefreshStatus: "available"
    };
    try {
      const result = await import_axios.default.post(this.basePath + "/private/registerdevice ", import_querystring.default.stringify(params));
      const registeration = result.data.response?.checkin;
      return registeration;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  async addHereNow(checkin, females_only = true) {
    const hereNow = checkin?.venue?.hereNow;
    this.log(`Adding hereNows from ${checkin.venue.name}`);
    this.log(`Females only setting is ${females_only}`);
    this.log(`Found ${hereNow.count} people checked in classified under ${hereNow.groups.length} groups`);
    if (hereNow.count > 0) {
      for (const group of hereNow.groups) {
        this.log(`Found ${group.count} in group ${group.name}`);
        if (group.count > 0) {
          for (const item of group.items) {
            if (females_only) {
              if (item.user?.gender == "female") {
                await this.addFriendByID(item.user.id);
              }
            } else {
              await this.addFriendByID(item.user.id);
            }
          }
        }
      }
    } else {
      return "no one is here";
    }
  }
  async addFriendByID(user_id) {
    try {
      const result = await this.getUser(user_id.toString());
      const new_friend = result?.data?.response?.user;
      this.log(`Checking ${new_friend?.firstName}`);
      this.log(`Relationship status is ${new_friend.relationship}`);
      if (new_friend.relationship == "none") {
        const result2 = await import_axios.default.post(this.basePath + "users/" + user_id + "/request", import_querystring.default.stringify(this.config));
        this.log(`Added ${new_friend?.firstName}`);
        return result2.data.response.user.relationship;
      }
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  // auto add trending function
  async autoAddTrending(location_name, limit_trending) {
    const trending = await this.getTrending(limit_trending, void 0, location_name);
    for (const venue of trending) {
      if (venue.hereNow.count > 0) {
        this.log(`venue location is ${venue.location.lat} ${venue.location.lng}`);
        let checkin = await this.checkIn(venue.id, true);
        this.log(`my ll after checkin is ${this.getLL()}`);
        await this.addHereNow(checkin);
      }
    }
  }
  // Like Functions
  async likeCheckin(checkin_id) {
    try {
      const result = await import_axios.default.post(this.basePath + "checkins/" + checkin_id + "/like", import_querystring.default.stringify(this.config));
      return result;
    } catch (error) {
      this.error(error.response.data);
      return;
    }
  }
  async likeUnliked(limit = 40) {
    try {
      const succeeded = [];
      const failed = [];
      const recent = await this.getRecent(limit);
      for (const checkin of recent) {
        if (checkin.like == false) {
          const liked_result = await this.likeCheckin(checkin.id);
          this.log(`liked ${checkin.id}`);
          succeeded.push(liked_result);
        } else {
          failed.push(checkin.id);
        }
      }
      return { succeeded, failed };
    } catch (error) {
      this.error(error.response.data);
    }
  }
  getLL() {
    return this.config.ll;
  }
  log(message) {
    let _prefix = `${(/* @__PURE__ */ new Date()).toLocaleString()} - `;
    _prefix += typeof this?.user?.firstName != "undefined" ? this?.user?.firstName : this?.user?.id;
    console.log(`${_prefix}) `, message);
  }
  error(error) {
    let _prefix = `${(/* @__PURE__ */ new Date()).toLocaleString()} - `;
    _prefix += typeof this?.user?.firstName != "undefined" ? this?.user?.firstName : "unknown user";
    _prefix += " - Error: ";
    switch (error?.meta?.code) {
      case 401:
        console.error(`${_prefix} [${error.meta.errorType}] ${error.meta.errorDetail}`);
      default:
        console.error(JSON.stringify(`${_prefix} ${error}`, null, 4));
    }
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  SwarmappApi
});
